@@ -6,9 +6,9 @@ OC.L10N.register(
     "New note" : "Nova noto",
     "Distraction-free notes and writing" : "Sendistraj notoj kaj skribado",
     "There are unsaved notes. Leaving the page will discard all changes!" : "Estas nekonservitaj notoj. Foriro el la paĝo perdos ĉiujn ŝanĝojn!",
+    "Preview" : "Antaŭvidi",
     "Insert image" : "Enmeti bildon",
-    "Folder to store your notes" : "Dosiero, en kiu konservi viajn notojn",
-    "File extension for new notes" : "Dosiersufikso por novaj notoj",
+    "Files" : "Dosieroj",
     "All notes" : "Ĉiuj notoj",
     "Categories" : "Kategorioj",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
@@ -18,7 +18,6 @@ OC.L10N.register(
     "Delete note" : "Forigi noton",
     "Use current version" : "Uzi nunan version",
     "Edit" : "Modifi",
-    "Preview" : "Antaŭvidi",
     "Today" : "Hodiaŭ",
     "Yesterday" : "Hieraŭ",
     "Loading …" : "Ŝargado...",
