@@ -29,6 +29,7 @@ OC.L10N.register(
     "Insert link" : "Lisää linkki",
     "Insert image" : "Lisää kuva",
     "Switch between editor and viewer" : "Vaihda muokkaus- ja katselutilan välllä",
+    "General" : "Yleiset",
     "File extension" : "Tiedostopääte",
     "Mobile apps" : "Mobiilisovellukset",
     "Shortcuts" : "Pikanäppäimet",
@@ -40,6 +41,8 @@ OC.L10N.register(
     "Wrong image" : "Väärä kuva",
     "The file was not uploaded. Check your server logs." : "Tiedostoa ei ladattu. Tarkista palvelimen lokitiedot.",
     "Upload image" : "Lataa kuva",
+    "Android" : "Android",
+    "iPhone and iPad" : "iPhone ja iPad",
     "Remove from favorites" : "Poista suosikeista",
     "Add to favorites" : "Lisää suosikkeihin",
     "Error while renaming note." : "Virhe muuttaessa muistiinpanon nimeä.",
